@@ -30,15 +30,6 @@ class TestAppTestMMap:
         except FileNotFoundError:
             pass
 
-    def setup_method(self, meth):
-        if getattr(meth, 'is_large', False):
-            if sys.maxsize < 2**32 and not self.runappdirect:
-                # this fails because it uses ll2ctypes to call the posix
-                # functions like 'open' and 'lseek', whereas a real compiled
-                # C program would macro-define them to their longlong versions
-                py.test.skip("emulation of files can't use "
-                             "larger-than-long offsets")
-
     def test_page_size(self):
         import mmap
         assert mmap.PAGESIZE > 0
@@ -378,8 +369,10 @@ class TestAppTestMMap:
 
     def test_resize(self):
         import sys
-        if ("darwin" in sys.platform) or ("freebsd" in sys.platform):
-            skip("resize does not work under OSX or FreeBSD")
+        if ("darwin" in sys.platform or
+            "freebsd" in sys.platform or
+            "openbsd" in sys.platform):
+            skip("resize does not work under OSX, FreeBSD or OpenBSD")
 
         import mmap
         import os
@@ -402,8 +395,10 @@ class TestAppTestMMap:
 
     def test_resize_bsd(self):
         import sys
-        if ("darwin" not in sys.platform) and ("freebsd" not in sys.platform):
-            skip("resize works under not OSX or FreeBSD")
+        if ("darwin" not in sys.platform and
+            "freebsd" not in sys.platform and
+            "openbsd" not in sys.platform):
+            skip("resize works under on platforms besides OSX, FreeBSD and OpenBSD")
 
         import mmap
         import os
@@ -729,7 +724,10 @@ class TestAppTestMMap:
         raises(ValueError, m.seek, -len(m) - 1, 2)
 
         # try resizing map
-        if not (("darwin" in sys.platform) or ("freebsd" in sys.platform)):
+        if not(
+            "darwin" in sys.platform or
+            "freebsd" in sys.platform or
+            "openbsd" in sys.platform):
             m.resize(512)
 
             assert len(m) == 512
